Learn R Programming

ReactomePA (version 1.12.3)

enrichPathway: Pathway Enrichment Analysis of a gene set. Given a vector of genes, this function will return the enriched pathways with FDR control.

Description

Pathway Enrichment Analysis of a gene set. Given a vector of genes, this function will return the enriched pathways with FDR control.

Usage

enrichPathway(gene, organism = "human", pvalueCutoff = 0.05, pAdjustMethod = "BH", qvalueCutoff = 0.2, universe, minGSSize = 5, readable = FALSE)

Arguments

gene
a vector of entrez gene id.
organism
one of "human", "rat", "mouse", "celegans", "zebrafish", "fly".
pvalueCutoff
Cutoff value of pvalue.
pAdjustMethod
one of "holm", "hochberg", "hommel", "bonferroni", "BH", "BY", "fdr", "none"
qvalueCutoff
Cutoff value of qvalue
universe
background genes
minGSSize
minimal size of genes annotated by Ontology term for testing.
readable
whether mapping gene ID to gene Name

Value

A enrichResult instance.

See Also

enrichResult-class

Examples

Run this code
gene <- c("11171", "8243", "112464", "2194",
				"9318", "79026", "1654", "65003",
				"6240", "3476", "6238", "3836",
				"4176", "1017", "249")
	yy = enrichPathway(gene, pvalueCutoff=0.05)
	head(summary(yy))
	#plot(yy)

Run the code above in your browser using DataLab